@@ -580,7 +580,7 @@ def preview_node_inputs(
     node_id: str,
     subprocess_stack: List[str] = [],
     root_pipeline_data: dict = {},
-    current_constants: dict = {},
+    parent_params: dict = {},
 ):
     """
     预览某个节点的输入结果
@@ -591,29 +591,34 @@ def preview_node_inputs(
     :type node_id: str
     :param subprocess_stack: 子流程，需保证顺序
     :type subprocess_stack: List[str]
-    :param root_pipeline_data: 流程数据
-    :param current_constants: 当前变量
+    :param root_pipeline_data: root流程数据
+    :param parent_params: 父流程传入参数
     :return: 执行结果
     :rtype: EngineAPIResult
     """
-    total_constants = {**current_constants, **pipeline["data"].get("inputs", {})}
     context_values = [
         ContextValue(key=key, type=VAR_CONTEXT_MAPPING[info["type"]], value=info["value"], code=info.get("custom_type"))
-        for key, info in total_constants.items()
+        for key, info in list(pipeline["data"].get("inputs", {}).items()) + list(parent_params.items())
     ]
     context = Context(runtime, context_values, root_pipeline_data)
 
     if subprocess_stack:
         subprocess = subprocess_stack[0]
         child_pipeline = pipeline["activities"][subprocess]["pipeline"]
-        param_data = {key: context.variables[key] for key, info in total_constants.items() if info["is_param"]}
+        param_data = {
+            key: info["value"]
+            for key, info in pipeline["activities"][subprocess]["params"].items()
+        }
+        hydrated_context = context.hydrate(deformat=True)
+        hydrated_param_data = Template(param_data).render(hydrated_context)
+        formatted_param_data = {key: {"value": value, "type": "plain"} for key, value in hydrated_param_data.items()}
         return preview_node_inputs(
             runtime=runtime,
             pipeline=child_pipeline,
             node_id=node_id,
             subprocess_stack=subprocess_stack[1:],
-            root_pipeline_data={**root_pipeline_data, **param_data},
-            current_constants=total_constants,
+            root_pipeline_data=root_pipeline_data,
+            parent_params=formatted_param_data,
         )
     raw_inputs = pipeline["activities"][node_id]["component"]["inputs"]
     raw_inputs = {key: info["value"] for key, info in raw_inputs.items()}
