@@ -247,6 +247,46 @@ class Engine:
 
         self.runtime.post_retry_node(node_id, data)
 
+    def retry_subprocess(self, node_id: str):
+        """
+        重试进入失败的子流程
+
+        :param node_id: 子流程 ID
+        :type node_id: str
+        :raises InvalidOperationError: [description]
+        """
+        node = self.runtime.get_node(node_id)
+
+        if not node.type is NodeType.SubProcess:
+            raise InvalidOperationError("node({}) type is not SubProcess".format(node_id))
+
+        state = self.runtime.get_state(node_id)
+
+        process_id = self._ensure_state_is_fail_and_return_process_id(state)
+
+        self.runtime.pre_retry_subprocess(node_id)
+
+        proc_info = self.runtime.get_process_info(process_id)
+
+        # reset pipeline stack
+        if proc_info.pipeline_stack[-1] == node_id:
+            self.runtime.set_pipeline_stack(process_id, proc_info.pipeline_stack[:-1])
+
+        self._add_history(node_id, state)
+
+        self.runtime.set_state(
+            node_id=node_id,
+            to_state=states.READY,
+            is_retry=True,
+            refresh_version=True,
+            clear_started_time=True,
+            clear_archived_time=True,
+        )
+
+        self.runtime.execute(process_id, node_id)
+
+        self.runtime.post_retry_subprocess(node_id)
+
     def skip_node(self, node_id: str):
         """
         跳过失败的节点继续执行
