@@ -24,9 +24,7 @@ logger = logging.getLogger("bamboo_engine")
 
 @register_handler(NodeType.EmptyEndEvent)
 class EmptyEndEventHandler(NodeHandler):
-    def execute(
-        self, process_info: ProcessInfo, loop: int, inner_loop: int, version: str
-    ) -> ExecuteResult:
+    def execute(self, process_info: ProcessInfo, loop: int, inner_loop: int, version: str) -> ExecuteResult:
         """
         节点的 execute 处理逻辑
 
@@ -54,9 +52,7 @@ class EmptyEndEventHandler(NodeHandler):
             context_outputs,
         )
 
-        context_values = self.runtime.get_context_values(
-            pipeline_id=pipeline_id, keys=context_outputs
-        )
+        context_values = self.runtime.get_context_values(pipeline_id=pipeline_id, keys=context_outputs)
         logger.info(
             "[%s] %s context values: %s",
             root_pipeline_id,
@@ -78,15 +74,12 @@ class EmptyEndEventHandler(NodeHandler):
             outputs[key] = hydrated_context.get(key, key)
         if not root_pipeline_finished:
             outputs[self.LOOP_KEY] = subproc_state.loop + Settings.RERUN_INDEX_OFFSET
+            outputs[self.INNER_LOOP_KEY] = subproc_state.inner_loop + Settings.RERUN_INDEX_OFFSET
         self.runtime.set_execution_data_outputs(node_id=pipeline_id, outputs=outputs)
 
-        self.runtime.set_state(
-            node_id=self.node.id, to_state=states.FINISHED, set_archive_time=True
-        )
+        self.runtime.set_state(node_id=self.node.id, to_state=states.FINISHED, set_archive_time=True)
 
-        self.runtime.set_state(
-            node_id=pipeline_id, to_state=states.FINISHED, set_archive_time=True
-        )
+        self.runtime.set_state(node_id=pipeline_id, to_state=states.FINISHED, set_archive_time=True)
 
         # root pipeline finish
         if root_pipeline_finished:
@@ -102,9 +95,7 @@ class EmptyEndEventHandler(NodeHandler):
 
         # subprocess finish
         subprocess = self.runtime.get_node(pipeline_id)
-        self.runtime.set_pipeline_stack(
-            process_info.process_id, process_info.pipeline_stack
-        )
+        self.runtime.set_pipeline_stack(process_info.process_id, process_info.pipeline_stack)
 
         # extract subprocess outputs to parent context
         subprocess_outputs = self.runtime.get_data_outputs(pipeline_id)
